@@ -609,6 +609,10 @@ jsSurveyGadget <- function(data, nfactor.limit = 20) {
                 options = c(jstable::opt.tbreg("timeroctable"), list(scrollX = TRUE)))
     })
 
+    session$onSessionEnded(function() {
+      stopApp()
+    })
+
   }
 
 
@@ -961,6 +965,10 @@ jsSurveyExtAddin <- function(nfactor.limit = 20, max.filesize = 2048){
                 options = c(jstable::opt.tbreg("roctable"), list(scrollX = TRUE)))
     })
 
+    session$onSessionEnded(function() {
+      stopApp()
+    })
+
   }
 
   #viewer <- dialogViewer("Descriptive statistics", width = 1100, height = 850)
